@@ -25,3 +25,12 @@ declare -A expected
 expected[sel-indent_data1]='^hello$'
 expected[sel-indent_data2]='^world$'
 source 'test.sh'
+
+# _cmd_insert_auto_indent_*
+macro='M-o a 0 enter f o r space { enter i = 1 enter } enter'
+extra_opts='-i 1'
+declare -A expected
+expected[auto-indent-1]='^for {$'
+expected[auto-indent-2]='^\ti=1$'
+expected[auto-indent-3]='^}$'
+source 'test.sh'
