@@ -2,7 +2,9 @@
 
 #define comma ,
 
-MAIN("he\tllo\t\t",
+char *str = "he\tllo\t\t";
+
+void test(buffer_t *buf, mark_t *cur) {
     bint_t i;
     bint_t char_vcols_4[8] = {0 comma  1 comma  2 comma  4 comma  5 comma  6 comma  7 comma  8};
     bint_t char_vcols_2a[8] = {0 comma  1 comma  2 comma  4 comma  5 comma  6 comma  7 comma  8};
@@ -34,4 +36,4 @@ MAIN("he\tllo\t\t",
     for (i = 0; i < buf->first_line->char_count; i++) {
         ASSERT("vcol2b", char_vcols_2b[i], buf->first_line->chars[i].vcol);
     }
-)
+}
