@@ -1,7 +1,9 @@
 #include "test.h"
 
-MAIN("hi",
-    char* data;
+char *str = "hi";
+
+void test(buffer_t *buf, mark_t *cur) {
+    char *data;
     bint_t data_len;
 
     buffer_delete(buf, 0, 1);
@@ -13,4 +15,4 @@ MAIN("hi",
     buffer_undo(buf);
     buffer_get(buf, &data, &data_len);
     ASSERT("ins", 0, strncmp(data, "hi", data_len));
-)
+}
