@@ -1,9 +1,11 @@
 #include "test.h"
 
-MAIN("hello\nworld",
-    mark_t* lett1;
-    mark_t* lett2;
-    mark_t* lett3;
+char *str = "hello\nworld";
+
+void test(buffer_t *buf, mark_t *cur) {
+    mark_t *lett1;
+    mark_t *lett2;
+    mark_t *lett3;
 
     mark_clone_w_letter(cur, 'a', &lett1);
     ASSERT("neq1", 1, lett1 != cur ? 1 : 0);
@@ -17,4 +19,4 @@ MAIN("hello\nworld",
     ASSERT("null", 1, lett3 == NULL ? 1 : 0);
 
     mark_destroy(lett2);
-)
+}
