@@ -1,6 +1,8 @@
 #include "test.h"
 
-MAIN("hello\nworld",
+char *str = "hello\nworld";
+
+void test(buffer_t *buf, mark_t *cur) {
     mark_move_beginning(cur);
 
     mark_move_col(cur, 5);
@@ -8,5 +10,5 @@ MAIN("hello\nworld",
 
     mark_move_col(cur, 6);
     ASSERT("oob", 5, cur->col);
-)
+}
 
